--
-- HoseSystemFillArmInteractive
--
-- Authors: Wopster
-- Description: Custom functions for the fillArm
--
-- Copyright (c) Wopster, 2017

HoseSystemFillArmInteractive = {}
---
-- @param specializations
--
function HoseSystemFillArmInteractive.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(HoseSystemVehicle, specializations)
end

function HoseSystemFillArmInteractive:load(savegame)
    self.chainNode = Utils.indexToObject(self.components, getXMLString(self.xmlFile, 'vehicle.hoseSystemFillArm#chainNode'))
    self.chainNodeMovingToolIndice = Utils.getNoNil(getXMLInt(self.xmlFile, 'vehicle.hoseSystemFillArm#chainNodeMovingToolIndice'), 0) + 1
    self.armNodeMovingToolIndice = Utils.getNoNil(getXMLInt(self.xmlFile, 'vehicle.hoseSystemFillArm#armNodeMovingToolIndice'), 0) + 1
    self.armLockMaxRot = math.rad(Utils.getNoNil(getXMLFloat(self.xmlFile, 'vehicle.hoseSystemFillArm#armLockMaxRot'), -1))
    self.armLockActivationMovingToolIndice = Utils.getNoNil(getXMLInt(self.xmlFile, 'vehicle.hoseSystemFillArm#armLockActivationMovingToolIndice'), 0) + 1
    self.armLockActivationRot = math.rad(Utils.getNoNil(getXMLFloat(self.xmlFile, 'vehicle.hoseSystemFillArm#armLockActivationRot'), 2.5))
end

function HoseSystemFillArmInteractive:delete()
end

function HoseSystemFillArmInteractive:mouseEvent(...)
end

function HoseSystemFillArmInteractive:keyEvent(...)
end

function HoseSystemFillArmInteractive:update(dt)
    if not self.isClient then
        return
    end

    if self:getIsActive() then
        local tool = self.movingTools[self.chainNodeMovingToolIndice]

        if tool ~= nil then
            setShaderParameter(self.chainNode, "offsetUV", -tool.curRot[2] + dt * tool.lastRotSpeed, 0, 0, 0, false)
        end
    end
end

function HoseSystemFillArmInteractive:updateTick(dt)
    if self:getIsActive() then
        local toolArm = self.movingTools[self.armLockActivationMovingToolIndice]
        local tool = self.movingTools[self.armNodeMovingToolIndice]

        if toolArm ~= nil and tool ~= nil then
            if tool.orgRotMin == nil then
                tool.orgRotMin = tool.rotMin
            end

            if toolArm.orgRotMin == nil then
                toolArm.orgRotMin = toolArm.rotMin
            end

            if tool.curRot[2] <= self.armLockActivationRot then
                if toolArm.curRot[1] <= self.armLockMaxRot then
                    tool.rotMin = math.max(0, self.armLockActivationRot)
                else
                    toolArm.rotMin = math.max(0, self.armLockMaxRot)

                    if tool.rotMin ~= tool.orgRotMin then
                        tool.rotMin = tool.orgRotMin
                    end
                end
            else
                if toolArm.rotMin ~= toolArm.orgRotMin then
                    toolArm.rotMin = toolArm.orgRotMin
                end

                if tool.rotMin ~= tool.orgRotMin then
                    tool.rotMin = tool.orgRotMin
                end
            end
        end
    end
end

function HoseSystemFillArmInteractive:draw()
end